@@ -21,7 +21,6 @@ from django.template.loader import render_to_string
 from django.utils.text import capfirst
 from django.utils.translation import ugettext as _
 
-import reversion
 from reversion.admin import VersionAdmin
 from reversion.models import Version, VERSION_TYPE_CHOICES, VERSION_CHANGE, \
     has_int_pk
@@ -30,7 +29,6 @@ from reversion_compare.forms import SelectDiffForm
 from reversion_compare.helpers import html_diff, compare_queryset
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
-from reversion import get_adapter
 
 
 logger = logging.getLogger(__name__)
@@ -97,8 +95,7 @@ class CompareObject(object):
     def get_related(self):
         if self.field.rel is not None:
             obj = self.version.object_version.object
-            field_name = self.field.name
-            related = getattr(obj, field_name)
+            related = getattr(obj, self.field.name)
             return related
 
     def get_many_to_many(self):
@@ -122,10 +119,10 @@ class CompareObject(object):
             content_type=ContentType.objects.get_for_model(related_model),
             object_id__in=ids
         )
-#        logger.debug("m2m queryset:", queryset)
+#        logger.debug("m2m queryset: %s", queryset)
 
         versions = sorted(list(queryset))
-#        logger.debug("versions:", versions)
+#        logger.debug("versions: %s", versions)
 
         if self.has_int_pk:
             # The primary_keys would be stored in a text field -> convert it to integers
@@ -197,14 +194,14 @@ class CompareObject(object):
 
 
 class CompareObjects(object):
-    def __init__(self, field, field_name, obj, version1, version2):
+    def __init__(self, field, field_name, obj, version1, version2, manager):
         self.field = field
         self.field_name = field_name
         self.obj = obj
 
         model = self.obj.__class__
         self.has_int_pk = has_int_pk(model)
-        self.adapter = get_adapter(model) # VersionAdapter instance
+        self.adapter = manager.get_adapter(model) # VersionAdapter instance
 
         # is a related field (ForeignKey, ManyToManyField etc.)
         self.is_related = self.field.rel is not None
@@ -273,22 +270,22 @@ class CompareObjects(object):
 #        missing_objects_pk2 = [obj.pk for obj in missing_objects2]
         missing_objects_dict2 = dict([(obj.pk, obj) for obj in missing_objects2])
 
-        # logger.debug("missing_objects1:", missing_objects1)
-        # logger.debug("missing_objects2:", missing_objects2)
-        # logger.debug("missing_ids1:", missing_ids1)
-        # logger.debug("missing_ids2:", missing_ids2)
+        # logger.debug("missing_objects1: %s", missing_objects1)
+        # logger.debug("missing_objects2: %s", missing_objects2)
+        # logger.debug("missing_ids1: %s", missing_ids1)
+        # logger.debug("missing_ids2: %s", missing_ids2)
 
         missing_object_set1 = set(missing_objects1)
         missing_object_set2 = set(missing_objects2)
-        # logger.debug(missing_object_set1, missing_object_set2)
+        # logger.debug("%s %s", missing_object_set1, missing_object_set2)
 
         same_missing_objects = missing_object_set1.intersection(missing_object_set2)
         removed_missing_objects = missing_object_set1.difference(missing_object_set2)
         added_missing_objects = missing_object_set2.difference(missing_object_set1)
 
-        # logger.debug("same_missing_objects:", same_missing_objects)
-        # logger.debug("removed_missing_objects:", removed_missing_objects)
-        # logger.debug("added_missing_objects:", added_missing_objects)
+        # logger.debug("same_missing_objects: %s", same_missing_objects)
+        # logger.debug("removed_missing_objects: %s", removed_missing_objects)
+        # logger.debug("added_missing_objects: %s", added_missing_objects)
 
 
         # Create same_items, removed_items, added_items with related m2m items
@@ -318,19 +315,19 @@ class CompareObjects(object):
             else:
                 version2 = None
 
-            #logger.debug("%r - %r - %r" % (primary_key, version1, version2))
+            #logger.debug("%r - %r - %r", primary_key, version1, version2)
 
             if version1 is not None and version2 is not None:
                 # In both -> version changed or the same
                 if version1.serialized_data == version2.serialized_data:
-                    #logger.debug("same item:", version1)
+                    #logger.debug("same item: %s", version1)
                     same_items.append(version1)
                 else:
                     changed_items.append((version1, version2))
             elif version1 is not None and version2 is None:
                 # In 1 but not in 2 -> removed
-                #logger.debug(primary_key, missing_objects_pk2)
-                #logger.debug(repr(primary_key), repr(missing_objects_pk2))
+                #logger.debug("%s %s", primary_key, missing_objects_pk2)
+                #logger.debug("%s %s", repr(primary_key), repr(missing_objects_pk2))
                 if primary_key in missing_objects_dict2:
                     missing_object = missing_objects_dict2[primary_key]
                     added_missing_objects.remove(missing_object)
@@ -340,7 +337,7 @@ class CompareObjects(object):
                 removed_items.append(version1)
             elif version1 is None and version2 is not None:
                 # In 2 but not in 1 -> added
-                #logger.debug("added:", version2)
+                #logger.debug("added: %s", version2)
                 added_items.append(version2)
             else:
                 raise RuntimeError()
@@ -362,8 +359,8 @@ class CompareObjects(object):
             return
         logger.debug("_______________________________")
         logger.debug(" *** CompareObjects debug: ***")
-        logger.debug("changed:", self.changed())
-        logger.debug("follow:", self.follow)
+        logger.debug("changed: %s", self.changed())
+        logger.debug("follow: %s", self.follow)
 
         debug1 = self.compare_obj1.get_debug()
         debug2 = self.compare_obj2.get_debug()
@@ -523,7 +520,7 @@ class BaseCompareVersionAdmin(VersionAdmin):
         """
         def _get_compare_func(suffix):
             func_name = "compare_%s" % suffix
-            # logger.debug("func_name:", func_name)
+            # logger.debug("func_name: %s", func_name)
             if hasattr(self, func_name):
                 func = getattr(self, func_name)
                 return func
@@ -564,7 +561,7 @@ class BaseCompareVersionAdmin(VersionAdmin):
         has_unfollowed_fields = False
 
         for field in fields:
-            #logger.debug(field, field.db_type, field.get_internal_type())
+            #logger.debug("%s %s %s", field, field.db_type, field.get_internal_type())
 
             field_name = field.name
 
@@ -573,7 +570,7 @@ class BaseCompareVersionAdmin(VersionAdmin):
             if self.compare_exclude and field_name in self.compare_exclude:
                 continue
 
-            obj_compare = CompareObjects(field, field_name, obj, version1, version2)
+            obj_compare = CompareObjects(field, field_name, obj, version1, version2, self.revision_manager)
             #obj_compare.debug()
 
             is_related = obj_compare.is_related
@@ -616,7 +613,7 @@ class BaseCompareVersionAdmin(VersionAdmin):
 
         object_id = unquote(object_id) # Underscores in primary key get quoted to "_5F"
         obj = get_object_or_404(self.model, pk=object_id)
-        queryset = reversion.get_for_object(obj)
+        queryset = self.revision_manager.get_for_object(obj)
         version1 = get_object_or_404(queryset, pk=version_id1)
         version2 = get_object_or_404(queryset, pk=version_id2)
 
